/***
 * Juliac
 * Copyright (C) 2012-2013a, Univ. Lille 1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@ow2.org
 *
 * Author: Lionel Seinturier
 */

package org.objectweb.fractal.koch.factory;

import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.koch.factory.MPrimitiveImpl;

/**
 * <p>
 * Interface implemented by binding control-component. This interface provides
 * a method for injecting the reference of the control part into the
 * implementation of a binding control-component.
 * </p>
 * 
 * <p>
 * For other types of control-components, this injection relies on the {@link
 * org.objectweb.fractal.api.control.BindingController} interface. See for
 * example
 * {@link MPrimitiveImpl#MPrimitiveImpl(org.objectweb.fractal.api.Type, Object)}. 
 * Yet, we cannot rely on this convention for binding control-component, since
 * it conflicts with the purpose of the control-component that is to implement
 * the {@link org.objectweb.fractal.api.control.BindingController} interface.
 * </p>
 * 
 * TODO move this interface to koch-runtime
 * 
 * @author Lionel Seinturier <Lionel.Seinturier@univ-lille1.fr>
 * @since 2.5
 */
public interface MBindingControlComponent {

	/**
	 * Set the value of the control-part.
	 * 
	 * @param owner  the reference of the control-part
	 */
	public void setFcOwner( Component owner );
}
