/***
 * Juliac
 * Copyright (C) 2012-2013a, Univ. Lille 1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@ow2.org
 *
 * Author: Lionel Seinturier
 */

package org.objectweb.fractal.runtime.ultracomp;

/**
 * Utility class.
 * 
 * @author Lionel Seinturier <Lionel.Seinturier@univ-lille1.fr>
 * @since 2.5
 */
public class UltraCompUtils {

	/**
	 * Name prefix for mComposite components that hold the component-based
	 * control membrane, the interceptor components and the content component.
	 */
	public static final String TOP_LEVEL_PREFIX = "/";
	
	/**
	 * The name of the content component.
	 */
	final public static String CONTENT_COMPONENT_NAME = "Ccontent";

	/**
	 * Name prefix for interceptor components.
	 */
	public static final String INTERCEPTOR_COMPONENT_PREFIX = "IC";

    /**
     * Return a version of the specified String suitable to be used as a Java
     * identifier by encoding all non suitable character by the sequence
     * composed of the underscore character followed by its ASCII code.
     * 
     * @param str  the input string
     * @return     the encoded string suitable for a Java identifier
     */
    public static String toIdentifier( String str ) {
    	
    	if( str == null ) {
    		return null;
    	}
    	
    	StringBuffer sb = new StringBuffer();
    	
    	for (int i = 0; i < str.length(); i++) {
        	char c = str.charAt(i);
        	boolean b =
        		c=='_' ? false :  // Encode _ in all cases
        			( i==0 ?
    					Character.isJavaIdentifierStart(c) :
						Character.isJavaIdentifierPart(c) );
        	if( b ) {
        		sb.append(c);
        	}
        	else {
        		// Non legal character in an identifier: encode it
        		sb.append('_');
        		String sub = str.substring(i,i+1);
        		byte[] bytes = sub.getBytes();
        		int integer = new Byte(bytes[0]).intValue();
        		String s = Integer.toHexString(integer);
        		sb.append(s);
        	}
		}
    	
    	return sb.toString();
    }
}
